package scid

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Scid.HSource

Sourceval valid : string

The valid SCID header.

Sourceval size : int

size is the size of the SCID header, in bytes.

Sourceval check : Bytes.t -> int -> (unit, string) Result.result

check b p is Ok () if b contains a valid header starting at p, and Error msg otherwise

Sourceval write : ?start:int -> ?len:int -> Bytes.t -> int -> unit

write ~start ~len b p write the portion of the valid SCID header starting at start, of length len, to b at p.