You can search for identifiers within the package.
in-package search v0.2.0
scid
Scid.H
val valid : string
The valid SCID header.
val size : int
size is the size of the SCID header, in bytes.
size
val check : Bytes.t -> int -> (unit, string) Result.result
check b p is Ok () if b contains a valid header starting at p, and Error msg otherwise
check b p
Ok ()
b
p
Error msg
val write : ?start:int -> ?len:int -> Bytes.t -> int -> unit
write ~start ~len b p write the portion of the valid SCID header starting at start, of length len, to b at p.
write ~start ~len b p
start
len